#
# spec file for package mysql-connector-java
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define new_name mysql-connector-j
Name:           mysql-connector-java
Version:        8.1.0
Release:        3.2
Summary:        Official JDBC Driver for MySQL
License:        GPL-2.0-or-later
Group:          Development/Languages/Java
URL:            https://dev.mysql.com/downloads/connector/j/
Source0:        https://github.com/mysql/mysql-connector-j/archive/refs/tags/%{version}.tar.gz#:/%{name}-%{version}.tar.gz
# NOTE:
#   the following file contains the generated protobuf files with
#   previous versions of protoc (protobuf) that are needed to build
#   in previous SUSE distros.
#   Source from:
#   https://github.com/mysql/mysql-connector-j/commit/6976d9d779b498c254fc5cab5e69cfc74fc3e4f0
Source1:        mysql-connector-java-generated-for-protobuf-3.9.2.tar.xz
Patch0:         javac-check.patch
# NOTE: Oracle OCI is not packaged yet
#   The patch doesn't remove the file AuthenticationOciClient.java
#   therefore it's removed during prep phase
Patch1:         %{name}-remove-oci-support.patch
Patch2:         reproducible-build.patch
BuildRequires:  ant
BuildRequires:  ant-contrib
BuildRequires:  apache-commons-logging
BuildRequires:  geronimo-jta-1_1-api
BuildRequires:  git
BuildRequires:  java-devel >= 1.8
BuildRequires:  javapackages-local
BuildRequires:  javassist >= 3.28.0
BuildRequires:  junit
BuildRequires:  protobuf-java >= 3.9.2
BuildRequires:  slf4j
BuildRequires:  xz
Requires:       jta >= 1.0
Requires:       slf4j
Provides:       mm.mysql = %{version}
Obsoletes:      mm.mysql < %{version}
# we'll be providing the new package name until this one is deprecated
Provides:       %{new_name}
# manual is no longer distributed
Provides:       %{name}-manual = %{version}
Obsoletes:      %{name}-manual < %{version}
BuildArch:      noarch
%if 0%{?suse_version} < 1500
BuildRequires:  log4j
Requires:       log4j
%else
BuildRequires:  reload4j
Requires:       reload4j
%endif

%description
MySQL Connector/J is a native Java driver that converts JDBC (Java
Database Connectivity) calls into the network protocol used by the
MySQL database. It lets developers working with the Java programming
language easily build programs and applets that interact with MySQL and
connect all corporate data, even in a heterogeneous environment. MySQL
Connector/J is a Type IV JDBC driver and has a complete JDBC feature
set that supports the capabilities of MySQL.

%prep
%setup -q -n mysql-connector-j-%{version}
%patch0 -p1
%patch1 -p1
%patch2 -p1

%if 0%{?suse_version} <= 1500 && 0%{?sle_version} <= 150200
# ship protobuf generated files compatible with protobuf 3.9.2
# which is the version we have in SLE15 SP2, the files were taken
# from commit 6976d9d779b498c254fc5cab5e69cfc74fc3e4f0, which is
# the last version compatible with that version of protobuf and
# are equivalent in functionality
tar -xvf %{SOURCE1} -C .
%endif

# remove OCI support
rm -rf src/main/protocol-impl/java/com/mysql/cj/protocol/a/authentication/AuthenticationOciClient.java

# extra libs
mkdir -p lib
mkdir -p src/lib
ln -f -s %{_datadir}/java/ant/ant-contrib.jar lib/ant-contrib.jar
ln -f -s %{_datadir}/java/slf4j/api.jar lib/slf4j-api.jar
ln -s %{_datadir}/java/javassist.jar lib/javassist.jar
ln -s %{_datadir}/java/protobuf.jar lib/protobuf.jar

%build

export CLASSPATH=$(build-classpath \
    ant-contrib \
    commons-logging \
    slf4j \
    jdbc-stdext\
    jta \
    junit \
    reload4j \
    protobuf)
%{ant} \
    -Dsnapshot.version= \
    -Dcom.mysql.jdbc.extra.libs=lib \
    -Dant.java.version=1.8 \
    -Dant.build.javac.source=1.8 \
    -Dant.build.javac.target=1.8 \
    -Dcom.mysql.cj.build.jdk=%{java_home} \
    -Dcom.mysql.cj.build.jdk.javac=%javac \
    -Dcom.mysql.cj.build.jdk.java=%java \
    build

%install
install -d -m 755 %{buildroot}%{_javadir}

install build/%{new_name}-%{version}-SNAPSHOT/%{new_name}-%{version}-SNAPSHOT.jar %{buildroot}%{_javadir}/%{new_name}.jar
ln -sf %{_javadir}/%{new_name}.jar %{buildroot}%{_javadir}/%{name}.jar

rm -rf %{buildroot}%{new_name}-%{version}/docs/release-test-output

install -d -m 755 %{buildroot}%{_mavenpomdir}

# Install the Maven build information as new name
%mvn_install_pom build/%{new_name}-%{version}-SNAPSHOT/pom.xml %{buildroot}%{_mavenpomdir}/JPP-%{new_name}.pom
sed -i 's/-SNAPSHOT//' %{buildroot}%{_mavenpomdir}/JPP-%{new_name}.pom
%add_maven_depmap JPP-%{new_name}.pom %{new_name}.jar -a com.mysql:%{name}

%files -f .mfiles
%{_javadir}/%{name}.jar
%license LICENSE
%doc CHANGES README

%changelog
* Tue Sep 26 2023 Fridrich Strba <fstrba@suse.com>
- Added patch:
  * reproducible-build.patch
    + keep PropertyDefinitions sorted to achieve reproducible order
    of getters/setters in generated class files
* Mon Sep 25 2023 Fridrich Strba <fstrba@suse.com>
- Avoid producing dupplicate maven data
* Thu Sep  7 2023 David Anes <david.anes@suse.com>
- Update to 8.1.0:
  - WL#15826, Deprecate autoDeserialize feature.
  - Fix for Bug#95039 (Bug#35534640), KeyManagementException:
    FIPS mode: only SunJSSE TrustManagers may be used.
  - Fix for Bug#110321 (Bug#35167701), Issue in JDBC
    PreparedStatement on adding NO_BACKSLASH_ESCAPES in sql_mode.
* Tue Jun  6 2023 Fridrich Strba <fstrba@suse.com>
- Wrap the reload4j/log4j dependencies in conditions, so that the
  package can be built on SLE12.
* Tue Apr 25 2023 David Anes <david.anes@suse.com>
- Security fix:
  - [CVE-2023-21971, bsc#1211247] Fix for unauthorized ability to
    cause a hang or frequently repeatable crash (complete DOS)
- Update to 8.0.33:
  - Fix for Bug#34558945, PS using setCharacterStream() fails with
    "Incorrect string value" if the Java program encoding is not
    UTF-8 after 8.0.29.
  - Fix for Bug#109013 (Bug#34772608), useServerPrepStmts and
    useLocalTransactionState could cause rollback failure.
  - Fix for bug Bug#108643 (Bug#34652568), Commit statement not
    effect when two params turns on.
  - Fix for Bug#34918989, Pluggable classes are initialized even
    when they cannot be used by Connector/J.
  - Fix for Bug#93415 (Bug#28992710), Documentation for
    getDefaultSchema() Needs Improvements.
  - Fix for Bug#110168 (Bug#35110706), yum update fails upgrading
    Connector/J package.
  - Fix for Bug#35018216, Problems with Connector/J RPM's: jar names
    renamed.
  - Fix for Bug#107577 (Bug#34325361), rewriteBatchedStatements not
    work when table column name contains 'value' string.
  - Fix for Bug#109377 (Bug#34900156), rewriteBatchedStatements
    doesn't work when parenthesis are found in values.
  - Fix for Bug#109808 (Bug#35021038), DatabaseMetaData#getPrimaryKeys
    should ordered by COLUMN_NAME.
  - Fix for Bug#109864 (Bug#35034666), Connector/J 8.0.32 hangs on
    MySQL 5.5 with prepared statements.
  - Fix for Bug#109807 (Bug#35021014), DatabaseMetaData#getTypeInfo
    should ordered by DATA_TYPE.
  - Fix for Bug#77368 (Bug#21321849), "LOAD DATA LOCAL INFILE"
    doesn't work properly with relative paths.
  - Fix for Bug#109243 (Bug#34852047), Judge whether the returned
    result set of the sql statement is incorrect.
  - WL#15490, Support OCI ephemeral key based authentication.
* Fri Jan 27 2023 David Anes <david.anes@suse.com>
- Ship protobuf 3.9.2 compatible generated files to support
  older distro versions.
  - Added file mysql-connector-java-generated-for-protobuf-3.9.2.tar.xz
* Thu Jan 26 2023 David Anes <david.anes@suse.com>
- Update to 8.0.32:
  - MysqlDataSource fails to URL encode database name when constructing JDBC URL.
  - serverSideStatementCache ignores resultSetType.
  - UpdatableResultSet does not properly handle unsigned primary key.
  - Connector/J 8 query with explain can not return ResultRow.
  - Add support to row alias on INSERT... ON DUPLICATE KEY UPDATE on batch mode.
  - connectionCollation ignored if characterEncoding is set.
  - Connector/J rejects UNION with CTE.
  - Malformed packet generation for `COM_STMT_EXECUTE`.
  - Connector/J client hangs after prepare & execute process with old version server.
  - Contribution: Fix name of relocation POM file.
  - Contribution: [PATCH] Remove superfluous use of boxing.
  - Contribution: Recognize "ON DUPLICATE KEY UPDATE" in "INSERT SET" Statement.
  - RPM and DEB builds broken after introducing javadoc for maven bundles.
  - Sonatype compliant POM and maven bundles.
  - Upgrade 3rd party libraries and tools.
  - Upgrade Protocol Buffers dependency to protobuf-java-3.21.9.
* Thu Dec  8 2022 David Anes <david.anes@suse.com>
- Rebased javac-check.patch to new build.xml.
- Changed ant target from "dist" to "build", as it's been renamed.
- As Oracle renamed the package to "mysql-connector-j", we are
  "providing" both names for now, but the package has to be renamed
  to accommodate the change because the old name will be deprecated
  at some point in the future without further notice.
- Update to 8.0.31:
  Functionality Added or Changed
  * Important Change: To comply with proper naming guidelines, the
    Maven groupId and artifactId for Connector/J have been changed
    to the following starting with this release:
    groupId: com.mysql
    artifactId: mysql-connector-j
  * The old groupId and artifactId can still be used for linking
    the Connector/J library, but they will point to a Maven
    relocation POM, redirecting users to the new coordinates.
    Please switch to the new coordinates as soon as possible, as
    the old coordinates could be discontinued anytime without
    notice. See Installing Connector/J Using Maven.
  * Also, to go with these changes, the .jar library for
    Connector/J has been renamed to mysql-connector-j-x.y.z for
    all channels of distribution by Oracle, not just the Maven
    repository.
  * Before release 8.0.29, Connector/J always interpolated byte
    arrays as hexadecimal literals when obtaining a prepared
    statement's string representation by the toString() method.
    Since 8.0.29, all byte array values were displayed as
  * * BYTE ARRAY DATA ** when converted to strings. The same is
    also true for null values.
  * To allow different ways to display byte array data and null
    values, a new connection property, maxByteArrayAsHex, has been
    introduced: byte arrays shorter than the value of
    maxByteArrayAsHex are now shown as hexadecimal literals like
    before release 8.0.29. Any byte arrays longer than this value
    are interpolated generically as ** BYTE ARRAY DATA **.
  Bugs Fixed
  * X DevAPI: When parsing a string into a JSON string, some
    escape character sequences were not parsed properly, causing
    the Server to throw a com.mysql.cj.exceptions.WrongArgumentException
    when receiving the JSON value. This fix ensures that escape
    sequences are handled properly.
  * X DevAPI: When using the modify() method on JSON documents,
    any backslashes inside a literal to be used for the modification
    were lost. This fix corrects the mistakes in the expression
    parser that caused the issue.
  * Executing a PreparedStatment after applying setFetchSize(0) on
    it caused an ArrayIndexOutOfBoundsException.
  * Due to some old limitations, when used with Java applets,
    Connector/J found out the default character set on a system by
    various workarounds like reading the system property
    file.encoding, using an OutpuStreamWriter, etc. With this fix,
    Connector/J now uses Charset.defaultCharset(), the standard
    method for the purpose.
* Mon Aug  1 2022 David Anes <david.anes@suse.com>
- Update to 8.0.30:
  Functionality Added or Changed
  * X DevAPI: For document-modifying methods that are chained
    after modify() and take a document path expression as one of
    its arguments (that is, set(), unset(), arrayInsert(),
    arrayAppend()), Connector/J now throws an error when the
    document path is empty or is a null string.
  Bugs Fixed
  * Historically, MySQL Server has used utf8 as an alias for
    utf8mb3. Since release 8.0.29, utf8mb3 has become a recognized
    (though deprecated) character set on its own for MySQL Server
    and to make things consistent, in release 8.0.30, any
    collations prefixed with utf8_ are now prefixed with utf8mb3_
    instead. To go with that change, Connector/J has updated its
    character set and collation mapping accordingly in this
    release, and users are encouraged to update to Connector/J
    8.0.30 to avoid potential issues when working with MySQL
    Server 8.0.30 or later.
  * A few links in the CONTRIBUTING.md file in the distribution
    packages were broken. They have now been fixed or removed.
  * The description for the connection property
    rewriteBatchedStatements has been corrected, removing the
    limitation that server-sided prepared statements could not
    take advantage of the rewrite option.
  * A spelling error has been fixed in the source file for the
    PropertyDefinitions class. Thanks to Weijie Wu for
    contributing the fix.
  * DatabaseMetaData.getTypeInfo always returned false for
    AUTO_INCREMENT for all data types. With this fix, Connector/J
    returns the correct value for each data type. Also, the
    missing types DOUBLE UNSIGNED and DOUBLE PRECISION UNSIGNED
    have been added to the ResultSet.
  * Contrary to the the MySQL requirement for comments,
    Connector/J did not require a whitespace (or a control
    character such as a newline) after "--" to mark the beginning
    of a comment within a SQL statement. This fix aligns
    Connector/J with the MySQL requirement.
* Thu Apr 28 2022 David Anes <david.anes@suse.com>
- Update to 8.0.29:
  Functionality added or changed:
  * Historically, MySQL has used utf8 as an alias for utf8mb3.
    Since release 8.0.29, utf8mb3 has become a recognized (though
    deprecated) character set on its own for MySQL Server.
    Therefore, Connector/J has added utf8mb3 to its character set
    mapping, and users are encouraged to update to
    Connector/J 8.0.29 to avoid potential issues when working with
    MySQL Server 8.0.29 or later. (Bug #33850155)
  * A new connection property socksProxyRemoteDns has been added,
    which, when set to true, makes the SocksProxySocketFactory
    execute its own connect() implementation that passes the
    unresolved InetSocketAddress of a MySQL Server host to the
    created proxy socket, instead of having the address resolved
    locally. (Bug #77924, Bug #25710160)
  * The code for prepared statements has been refactored to make
    the code simpler and the logic for binding more consistent
    between ServerPreparedStatement and ClientPreparedStatement.
  * Connector/J now supports Fast Identity Online (FIDO)
    Authentication. See Connecting Using Fast Identity Online
    (FIDO) Authentication for details.
  Bugs fixed:
  * X DevAPI: If the connection property xdevapi.ssl-mode was set
    to DISABLED (or xdevapi.ssl-mode was not set, but the value
    was picked up from the sslMode setting), specifying some of
    the security properties caused Connector/J to throw an error.
    With this fix, even when encryption is turned off and
    irrelevant security properties are set, Connector/J does not
    throw an error.
  * DatabaseMetaData.getDefaultTransactionIsolation() returned a
    wrong value. It now returns the correct value of
    Connection.TRANSACTION_REPEATABLE_READ. (Bug #33723611)
  * Statement executions failed for replication connections when
    useCursorFetch was true and defaultFetchSize was greater than
    0. (Bug #25701740)
  * Prepared statements were parsed incorrectly sometimes when
    they contained comments marked by /* and */. (Bug #21978230)
  * A connection did not maintain the correct autocommit state
    when it was used in a pool with useLocalSessionState=true.
    (Bug #106435, Bug #33850099)
  * References: This issue is a regression of: Bug #33054827.
  * A spelling error in the error message for the buffer length
    being less than the expected payload length has been corrected.
    Thanks to Jianjian Song for contributing the fix.
    (Bug #106397, Bug #33893591)
  * When using client-side prepared statements, if the VALUES
    clause came after the ON DUPLICATE KEY UPDATE clause or it
    came at the end of the statement, a StringIndexOutOfBoundsException
    was thrown. This patch refactors the query parser to fix the
    problem behind the issue, and also to improve the parser's
    performance. (Bug #106240, Bug #33781440)
  * An unnecessary boxing has been removed from findColumn() in
    the ResultSetImpl class. Thanks to Pei Pei Ning for
    contributing this improvement. (Bug #106171, Bug #33757217)
  * When decoding decimals, the constructor used for creating the
    BigDecimal object has been changed from BigDecimal(String) to
    BigDecimal(char[]) in order to save memory. Thanks to Chen Yi
    for contributing to this improvement.
    (Bug #106065, Bug #33726184)
  * When inserting BigDecimal values into a database using
    rewritable server-side prepared statements with cursor-based
    fetching, the values suffered precision loss. (Bug #105915,
    Bug #33678490)
  * When the Connector/J logger level was at TRACE, a null bind
    value for a PreparedStatement resulted in a NullPointerException
    when the logger tried to read the value. This patch added a
    null check to avoid the exception to be thrown under the
    situation. (Bug #104349, Bug #33563548)
  * When the connection property rewriteBatchedStatements was set
    to true, inserting a BLOB using a prepared statement and
    executeBatch() resulted in a NullPointerException.
    (Bug #85317, Bug #25672958)
  * ResultSetMetaData and DatabaseMetaData returned Types.DATE for
    a YEAR table column even when yearIsDateType=false. With this
    fix, Types.SMALLINT was returned correctly in the situation.
    (Bug #82084, Bug #23743938)
  * A PreparedStatement could not be rewritten for batch insert if
    any table column involved contained "select" as a substring in
    the column name. (Bug #81468, Bug #23312764)
  * When using server-side prepared statements and the connection
    property profileSQL was set to true, setting a parameter of
    type LONGTEXT using a StringReader() resulted in a j
    ava.io.NotSerializableException. (Bug #62006, Bug #16714956)
  * Data truncation occurred for INOUT type parameters of data
    type BIT(1) for stored procedures. (Bug #38954, Bug #11749415)
* Fri Feb 25 2022 David Anes <david.anes@suse.com>
- Build now from GitHub official repo:
  * Updated source package to build from gihub official repository.
  * Remove utility generate-tarball.sh which is not needed anymore.
- Add patch to temporarily remove OCI IAM support while it's
  packaged:
  * Add mysql-connector-java-remove-oci-support.patch
- Update to 8.0.28 (CVE-2021-2471, bsc#1195557, jsc#PM-3307):
  Changes in 8.0.28:
  * Fix for Bug#99260 (31189960), statement.setQueryTimeout,creates a database connection and does not close.
  * Fix for Bug#103324 (32770013), X DevAPI Collection.replaceOne() missing matching _id check.
  * Fix for Bug#105197 (33461744), Statement.executeQuery() may return non-navigable ResultSet.
  * Fix for Bug#105323 (33507321), README.md contains broken links.
  * Fix for Bug#96900 (30355150), STATEMENT.CANCEL()CREATE A DATABASE CONNECTION BUT DOES NOT CLOSE THE CONNECTION.
  * Fix for Bug#104067 (33054827), No reset autoCommit after unknown issue occurs.
  * Fix for Bug#85223 (25656020), MYSQLSQLXML SETSTRING CRASH.
  * Fix for Bug#84365 (33425867), INSERT..VALUE with VALUES function lead to a StringIndexOutOfBoundsException.
  * Fix for Bug#105211 (33468860), class java.time.LocalDate cannot be cast to class java.sql.Date.
  * Fix for Bug#101389 (32089018), GETWARNINGS SHOULD CHECK WARNING COUNT BEFORE SENDING SHOW.
  * Fix for Bug#33488091, Remove all references to xdevapi.useAsyncProtocol from properties and code.
  * WL#14805, Remove support for TLS 1.0 and 1.1.
  * WL#14650, Support for MFA (multi factor authentication) authentication.
  Changesd in 8.0.27
  * Fix for Bug#103612 (32902019), Incorrectly identified WITH...SELECT as unsafe for read-only connections.
  * Fix for Bug#71929 (18346501), Prefixing query with double comments cancels query DML validation.
  * Fix for Bug#23204652, CURSOR POSITIONING API'S DOESNOT CHECK THE VALIDITY OF RESULTSET.
  * Fix for Bug#28725534, MULTI HOST CONNECTION WOULD BLOCK IN CONNECTION POOLING.
  * Fix for Bug#95139 (29807572), CACHESERVERCONFIGURATION APPEARS TO THWART CHARSET DETECTION.
  * Fix for Bug#104641 (33237255), DatabaseMetaData.getImportedKeys can return duplicated foreign keys.
  * Fix for Bug#33185116, Have method ResultSet.getBoolean() supporting conversion of 'T' and 'F' in a VARCHAR to True/False (boolean).
  * Fix for Bug#31117686, PROTOCOL ALLOWLIST NOT COMPATIBLE WITH IBM JAVA.
  * Fix for Bug#104559 (33232419), ResultSet.getObject(i, java.util.Date.class) throws NPE when the value is null.
  * WL#14707, Support OCI IAM authentication.
  * WL#14660, Testsuite with support for single MySQL server instance.
  * Fix for Bug#103878 (32954449), CONNECTOR/J 8 : QUERY WITH 'SHOW XXX' WILL GET EXCEPTION WHEN USE CURSOR.
  * Fix for Bug#103796 (32922715), CONNECTOR/J 8 STMT SETQUERYTIMEOUT CAN NOT WORK.
  * Fix for Bug#104170 (33064455), CONTRIBUTION: CLIENTPREPAREDSTMT: LEAVE CALENDAR UNTOUCHED.
  * Fix for Bug#95564 (29894324), createDatabaseIfNotExist is not working for databases with hyphen in name.
  Changes in 8.0.26
  * Fix for Bug#32954396, EXECUTEQUERY HANGS WITH USECURSORFETCH=TRUE & SETFETCHSIZE.
  * Fix for Bug#102372 (32459408), v8.0.23 unusable in OSGi.
  * Fix for Bug#25554464, CONNECT FAILS WITH NPE WHEN THE SERVER STARTED WITH CUSTOM COLLATION.
  * Fix for Bug#100606 (31818423), UNECESARY CALL TO "SET NAMES 'UTF8' COLLATE 'UTF8_GENERAL_CI'".
  * Fix for Bug#102404 (32435618), CONTRIBUTION: ADD TRACK SESSION STATE CHANGE.
  * Fix for Bug#95280 (29757140), DATABASEMETADATA.GETIMPORTEDKEYS RETURNS DOUBLE THE ROWS.
  * Fix for Bug#97269 (30438500), POSSIBLE BUG IN COM.MYSQL.CJ.XDEVAPI.STREAMINGDOCRESULTBUILDER.
  * Fix for Bug#103303 (32766143), JAVA.LANG.CLASSCASTEXCEPTION WHEN INSERTING BLOB WITH SERVER PREPARED STATEMENT.
  * WL#14205, Support query attributes.
  * WL#14411, Support for authentication_kerberos_client authentication plugin.
  * WL#14559, Deprecate TLS 1.0 and 1.1.
  * WL#14391, Migrate QA tests to main repo.
* Tue Feb 22 2022 Fridrich Strba <fstrba@suse.com>
- Do not build against the log4j12 packages, use the new reload4j
* Mon Jul 26 2021 Andreas Schwab <schwab@suse.de>
- Remove duplicate %%files section
* Mon Jul 19 2021 Johannes Grassler <johannes.grassler@suse.com>
- Remove hibernate-check.patch (fixed upstream)
- Remove mysql-connector-java-jdbc-4.1.patch (fixed upstream)
- Remove disable-testsuite.patch mysql-connector-java-jdbc-4.1.patch (fixed upstream)
- Remove compile-jdk7.patch (fixed upstream)
- Remove mysql-connector-java-sourcetarget.patch (fixed upstream)
- Refresh javac-check.patch
- Depend on log4j rather than log4j-mini and adjust log4j dependencies to
  account for the lack of log4j12 Provides in some code streams.
- Add missing Group tag
- Update to 8.0.25 (SOC-11543)
  Changes in 8.0.25
  * No functional changes: version alignment with MySQL Server 8.0.25.
  Changes in 8.0.24
  * Bug#102188 (32526663), AccessControlException with AuthenticationLdapSaslClientPlugin.
  * Bug#22508715, SETSESSIONMAXROWS() CALL ON CLOSED CONNECTION RESULTS IN NPE.
  * Bug#102131 (32338451), UPDATABLERESULTSET NPE WHEN USING DERIVED QUERIES OR VIEWS.
  * Bug#101596 (32151143), GET THE 'HOST' PROPERTY ERROR AFTER CALLING TRANSFORMPROPERTIES() METHOD.
  * Bug#20391832, SETOBJECT() FOR TYPES.TIME RESULTS IN EXCEPTION WHEN VALUE HAS FRACTIONAL PART.
  * Bug#97730 (31699993), xdev api: ConcurrentModificationException at Session.close.
  * Bug#99708 (31510398), mysql-connector-java 8.0.20 ASSERTION FAILED: Unknown message type: 57 s.close.
  * Bug#32122553, EXTRA BYTE IN COM_STMT_EXECUTE.
  * Bug#101558 (32141210), NULLPOINTEREXCEPTION WHEN EXECUTING INVALID QUERY WITH USEUSAGEADVISOR ENABLED.
  * Bug#102076 (32329915), CONTRIBUTION: MYSQL JDBC DRIVER RESULTSET.GETLONG() THROWS NUMBEROUTOFRANGE.
  * Bug#31747910, BUG 30474158 FIX IMPROVES JDBC COMPLIANCE BUT CHANGES DEFAULT RESULTSETTYPE HANDLING.
  * Bug#102321 (32405590), CALLING RESULTSETMETADATA.GETCOLUMNCLASSNAME RETURNS WRONG VALUE FOR DATETIME.
  * WL#14453, Pluggable authentication: new default behavior & user-less authentications.
  * WL#14392, Improve timeout error messages [classic].
  * WL#14202, XProtocol: Support connection close notification.
  Changes in 8.0.23
  * Bug#21789378, FORCED TO SET SERVER TIMEZONE IN CONNECT STRING.
  * Bug#95644 (30573281), JDBC GETDATE/GETTIME/GETTIMESTAMP INTERFACE BEHAVIOR CHANGE AFTER UPGRADE 8.0.
  * Bug#94457 (29402209), CONNECTOR/J RESULTSET.GETOBJECT( ..., OFFSETDATETIME.CLASS ) THROWS.
  * Bug#76775 (20959249), FRACTIONAL SECONDS IN TIME VALUES ARE NOT AVAILABLE VIA JDBC.
  * Bug#99013 (31074051), AN EXTRA HOUR GETS ADDED TO THE TIMESTAMP WHEN SUBTRACTING INTERVAL 'N' DAYS.
  * Bug#98695 (30962953), EXECUTION OF "LOAD DATA LOCAL INFILE" COMMAND THROUGH JDBC FOR DATETIME COLUMN.
  * Bug#101413 (32099505), JAVA.TIME.LOCALDATETIME CANNOT BE CAST TO JAVA.SQL.TIMESTAMP.
  * Bug#101242 (32046007), CANNOT USE BYTEARRAYINPUTSTREAM AS ARGUMENTS IN PREPARED STATEMENTS AN MORE.
  * WL#14274, Support for authentication_ldap_sasl_client(SCRAM-SHA-256) authentication plugin.
  * WL#14206, Support for authentication_ldap_sasl_client(GSSAPI) authentication plugin.
  * WL#14207, Replace language in APIs and source code/docs.
  Changes in 8.0.22
  * Bug#98667 (31711961), "All pipe instances are busy" exception on multiple connections to named Pipe.
  * Bug#96309 (31699357), MultiHost in loadbalance may lead to a TPS reduction during a quick switch.
  * Bug#99076 (31083755), Unclear exception/error when connecting with jdbc:mysql to a mysqlx port.
  * Bug#96870 (30304764), Contribution: Allow to disable AbandonedConnectionCleanupThread completely.
  * WL#14115, Support for authentication_ldap_sasl_client (SCRAM-SHA-1) authentication plugin.
  * WL#14096, Add option to specify LOAD DATA LOCAL allow list folder.
  * WL#13780, Skip system-wide trust and key stores (incl. X DevAPI client certs).
  * WL#14017, XProtocol -- support for configurable compression algorithms.
  * Bug#92903 (28834903), MySQL Connector/j should support wildcard names or alternative names.
  * Bug#99767 (31443178), Contribution: Check SubjectAlternativeName for TLS instead of commonName.
  * Bug#93444 (29015453), LOCALDATETIME PARAMETER VA UES ALTERED WHEN CLIENT AND SERVER TIMEZONES DIFFER.
  * WL#14052, Remove asynchronous variant of X Protocol.
  * Bug#99713 (31418928), NPE DURING COM.MYSQL.CJ.SERVERPREPAREDQUERYBINDVALUE.STOREDATE().
  * WL#14068, Remove legacy integration with JBoss.
  Changes in 8.0.21
  * WL#14051, Upgrade Protocol Buffers dependency to protobuf-java-3.11.4.
  * WL#14042, Upgrade testsuite to JUnit 5.
  * Bug#98237 (30911870),  PREPAREDSTATEMENT.SETOBJECT(I, "FALSE", TYPES.BOOLEAN) ALWAYS SETS TRUE OR 1.
  * WL#13008, DevAPI: Add schema validation to create collection.
  Changes in 8.0.20
  * Bug#30805426, IN CASE OF ISAUTHMETHODSWITCHREQUESTPACKET , TOSERVERS > 1 ARE IGNORED.
  * Bug#97714 (30570249), Contribution: Expose elapsed time for query interceptor
  * Bug#97724 (30570721), Contribution: Allow \'3.\' formatted numbers.
  * Bug#98536 (30877755), SIMPLEDATEFORMAT COULD CACHE A WRONG CALENDAR.
    Fix for Bug#91112 (28125069), AGAIN WRONG JAVA.SQL.DATE.
  * Bug#30474158, CONNECTOR/J 8 DOES NOT HONOR THE REQUESTED RESULTSETTYPE SCROLL_INSENSITIVE ETC.
  * Bug#98445 (30832513), Connection option clientInfoProvider=ClientInfoProviderSP causes NPE.
  * WL#12248, DevAPI: Connection compression.
  * Bug#30636056, ResultSetUtil.resultSetToMap() can be unsafe to use.
  * Bug#97757 (30584907), NULLPOINTEREXCEPTION WITH CACHERESULTSETMETADATA=TRUE AND EXECUTEQUERY OF "SET".
  Changes in 8.0.19
  * WL#13346, Support for mult-host and failover.
  * Bug#97413 (30477722), DATABASEMETADATA IS BROKEN AFTER SERVER WL#13528.
  * WL#13367, DNS SRV support.
  * WL#12736, DevAPI: Specify TLS ciphers to be used by a client or session.
  * Bug#96383 (30119545) RS.GETTIMESTAMP() HAS * DIFFERENT RESULTS FOR TIME FIELDS WITH USECURSORFETCH=TRUE.
  * Bug#96059 (29999318), ERROR STREAMING MULTI RESULTSETS WITH MYSQL-CONNECTOR-JAVA 8.0.X.
  * Bug#96442 (30151808), INCORRECT DATE ERROR WHEN CALLING GETMETADATA ON PREPARED STATEMENT.
  Changes in 8.0.18
  * WL#13347, Connectors should handle expired password sandbox without SET operations.
  * Bug#84098 (25223123), endless loop in LoadBalancedAutoCommitInterceptor.
  * Bug#23721537, MULTI-SELECT WITH EXECUTEASYNC() GIVES IMPROPER ERROR.
  * Bug#95741 (29898567), METADATA QUERY USES UPPER() AROUND NUMERIC EXPRESSION.
  * Bug#20913289, PSTMT.EXECUTEUPDATE() FAILS WHEN SQL MODE IS NO_BACKSLASH_ESCAPES.
  * Bug#80441 (22850444), SYNTAX ERROR ON RESULTSET.UPDATEROW() WITH SQL_MODE NO_BACKSLASH_ESCAPES.
  Changes in 8.0.17
  * WL#13210, Generate Javadocs via ant.
  * WL#12247, DevAPI: indexing array fields.
  * WL#12726, DevAPI: Add overlaps and not_overlaps as operator.
  * Bug#95503 (29821029), Operator IN not mapping consistently to the right X Plugin operation.
  * WL#12942, Update README.md and add new CONTRIBUTING.md.
  * WL#13125, Support fully qualified hostnames longer than 60 characters.
  * Bug#95210 (29807741), ClassCastException in BlobFromLocator when connecting as jdbc:mysql:replication.
  * Bug#29591275, THE JAR FILE NEEDS TO CONTAIN A README AND LICENSE FILE.
  * WL#13124, Support new utf8mb4 bin collation.
  * WL#13009, DevAPI: Deprecate methods.
  * WL#11101, Remove de-cache and close of SSPSs on double call to close().
  * Bug#89133 (27356869)  CONTRIBUTION: UPDATE DA ABASEMETADATA.JAVA.
  * Bug#11891000, DABATASEMETADATA.GETTABLES() IGNORES THE SCHEMA_PATTERN ARGUMENT.
  * Bug#94101 (29277648), SETTING LOGSLOWQUERIES SHOULD NOT AUTOMATICALLY ENABLE PROFILESQL FOR QUERIES.
  * Bug#74690 (20010454), PROFILEREVENT HOSTNAME HAS NO GETTER().
  * Bug#70677 (17640628), CONNECTOR J WITH PROFILESQL - LOG CONTAINS LOTS OF STACKTRACE DATA.
  * Bug#41172 (11750577), PROFILEREVENT.PACK() THROWS ARRAYINDEXOUTOFBOUNDSEXCEPTION.
  * Bug#27453692, CHARACTERS GET GARBLED IN CONCAT() IN PS WHEN USECURSORFETCH=TRUE.
  * Bug#94585 (29452669), GETTABLENAME() RETURNS NULL FOR A QUERY HAVING COUNT(*) WITH JDBC DRIVER V8.0.12.
  * Bug#94442 (29446059), RESULTSETIMPL.GETDOUBLE IS INEFFICIENT BECAUSE OF BIGDECIMAL (RE)CONSTRUCTIONS.
  Changes in 8.0.16
  * WL#12825, Remove third-party libraries from sources and bundles.
  * Bug#93590 (29054329), javax.net.ssl.SSLException: closing inbound before receiving peer's close_notify.
  * Bug#94414 (29384853), Connector/J RPM package have version number in path.
  * Bug#27786499, REDUNDANT FILES IN DEBIAN PACKAGE FOR DEBIAN9(COMMUNITY PACKAGE) FOR CJAVA.
  * WL#12246, DevAPI: Prepared statement support.
  * WL#10839, Adjust c/J tests to the new "ON" default for explicit_defaults_for_timestamp.
  * Bug#29329326, PLEASE AVOID SHOW PROCESSLIST IF POSSIBLE.
  * WL#12460, DevAPI: Support new session reset functionality.
  * WL#12459, DevAPI: Support connection-attributes.
  * Bug#25650385, GETBYTE() RETURNS ERROR FOR BINARY() FLD.
  * Bug#27784363, MYSQL 8.0 JDBC DRIVER THROWS NUMBERFORMATEXCEPTION FOR TEXT DATA
  * Bug#93007 (28860051), LoadBalancedConnectionProxy.getGlobalBlacklist bug.
  * Bug#29186870, CONNECTOR/J REGRESSION: NOT RETURNING PRECISION GETPROCEDURECOLUMNS.
  * Bug#22038729, X DEVAPI: ANY API CALL AFTER A FAILED CALL PROC() RESULTS IN HANG.
  * Bug#29244101, ADD MAPPING FOR UTF8MB4_ZH_0900_AS_CS COLLATION.
  * Bug#92819 (28834959), EXPRPARSER THROWS WRONGARGUMENTEXCEPTION WHEN PARSING EMPTY JSON ARRAY.
  * Bug#21921956, X DEVAPI: EXPRESSION PARSE ERROR WITH UNARY OPERATOR.
  * Bug#94031 (29257922), WRONG JSON_UNQUOTE WORKAROUND.
  * Bug#22931700, BINDINGS.GETBOOLEAN() ALWAYS RETURNS FALSE.
  * Bug#25650912, ERROR MESSAGE NOT CLEAR WHEN WE PASS A CHAR DATA TO ANY TABLE API.
  * Bug#25642021, CHANGEUSER() FAILS WHEN ENABLEPACKETDEBUG=TRUE.
  Changes in 8.0.15
  * Bug#94051 (29261254), Not recommended default for 'allowLoadLocalInfile'.
  Changes in 8.0.14
  * WL#12298, Connectors: Expose metadata about source and binaries in unified way.
  * Bug#93111 (28894344), ConnectionUrl.java contains char U+00A7 (section sign).
  * WL#12621, DevAPI: Handling of Default Schema.
  * Bug#93340 (28970166), C/J BUILD SCRIPT IS TOO VERBOSE
  * WL#12462, DevAPI: Be prepared for initial notice on connection.
  * Bug#28924137, WL#12463:IF COLLECTION DOESN'T EXIST, COLL.COUNT() IS GIVING A WRONG ERROR MESSAGE.
  * WL#12463, DevAPI: Standardize count method.
  * Bug#92508 (28747636), mysql-connector in bootclasspath causing memory leak.
  * Bug#25650514, UPDATEROW() CALL FAILS WITH NPE WHEN SSPS=TRUE AND TABLE HAS MULTI-FLD KEY.
  * Bug#25650482, REFRESHROW() CALL AFTER UPDATEROW() API FAILS WHEN USESERVERPREPSTMTS=TRUE.
  * Bug#92536 (28692243), UPDATEING SERVER SIDE PREPSTMTS RESULTSET FAIL.
  * Bug#92625 (28731795), CONTRIBUTION: FIX OBSERVED NPE IN CLEARINPUTSTREAM.
  * Bug#23045642, ADDING NO-DOC (MYSQLCONNJ-696) RESULTS IN EXCEPTION.
  * Bug#91065 (28101003), ZERODATETIMEBEHAVIOR=CONVERT_TO_NULL SHOULD NOT APPLY TO 00:00:00 TIME COLUMNS.
  * Bug#92574 (28706219), WHEN CONVERTING FROM VARCHAR TO JAVA BOOLEAN, 'N' IS NOT SUPPORTED.
  * Bug#25642226, CHANGEUSER() NOT SETTING THE DATABASE PROPERLY WITH SHA USER.
  * Bug#28606708, NAMED PIPE CONNECTION FOR X PROTOCOL RETURNS NPE, EXPECTED PROPER ERROR MESSAGE.
  Changes in 8.0.13
  * Bug#91317 (28207422), Wrong defaults on collation mappings.
  * WL#12245, DevAPI: Implement connect timeout.
  * Bug#21774249, UNIT TEST FAILS WITH ERROR " 'CEST' IS UNRECOGNIZED TIME ZONE".
  * WL#11857, DevAPI: Implement connection pooling for xprotocol.
  * Bug#91873 (28444461), REMOVE USEOLDUTF8BEHAVIOR CONNECTION PROPERTY.
  * Bug#92264 (28594434), JSONPARSER PUTS UNNECESSARY MAXIMUM LIMIT ON JSONNUMBER TO 10 DIGITS.
  * WL#12110, Extend PropertyDefinitions.PropertyKey usage.
  * Bug#81063 (23098159), w/ rewriteBatchedStatements, when 2 tables involved, the rewriting not correct.
  * Bug#84813 (25501750), rewriteBatchedStatements fails in INSERT.
  * Bug#81196 (23227334), CONNECTOR/J NOT FOLLOWING DATABASE CHARACTER SET.
  * Bug#72609 (18749544), SETDATE() NOT USING A PROLEPTIC GREGORIAN CALENDAR.
  * Bug#87534 (26730196), UNION ALL query fails when useServerPrepStmts=true on database connection.
  * Bug#89948 (27658489), Batched statements are not committed for useLocalTransactionState=true.
  * BUG#22305979, WRONG RECORD UPDATED IF SENDFRACTIONALSECONDS=FALSE AND SMT IS SCROLLABLE.
  * Bug#27102307, CHANGE USESSL AND VERIFYSERVERCERTIFICATE TO SSLMODE OPTION.
  * Bug#28150662, CONNECTOR/J 8 MALFORMED DATABASE URL EXCEPTION WHIT CORRECT URL STRING.
  * Bug#91421 (28246270), ALLOWED VALUES FOR ZERODATETIMEBEHAVIOR ARE INCOMPATIBLE WITH NETBEANS.
  * Bug#23045604, XSESSION.GETURI() RETURNS NPE.
  * Bug#21914769, NPE WHEN TRY TO EXECUTE INVALID JSON STRING.
  * Bug#BUG#90887 (28034570), DATABASEMETADATAUSINGINFOSCHEMA#GETTABLES FAILS IF METHOD ARGUMENTS ARE NULL.
  * Bug#28207088, C/JAVA: UPDATECLOB(INT COLUMNLABEL, JAVA.SQL.CLOB CLOB) IS FAILING.
  * Bug#27629553, NPE FROM GETSESSION() FOR SSL CONNECTION WHEN NO PASSWORD PASSED.
  Changes in 8.0.12
  * Bug#28208000, MASTER : HANG IN ASYNCHRONOUS SELECT TEST.
  * WL#10544, Update MySQL 8.0 keywords list.
  * WL#11858, DevAPI: Core API v1 alignment.
  * Bug#27652379, NPE FROM GETSESSION(PROPERTIES) WHEN HOST PARAMETER IS GIVEN IN SMALL LETTER.
  * BUG#87600 (26724154), CONNECTOR THROWS 'MALFORMED DATABASE URL' ON NON MYSQL CONNECTION-URLS.
  * BUG#26089880, GETCONNECTION("MYSQLX://..") RETURNS NON-X PROTOCOL CONNECTION.
  * WL#11876, Improve connection properties design.
  * WL#11933, Connector/J 8.0 X DevAPI reference documentation update.
  * WL#11860, Ensure >= 75%% code coverage.
  * Bug#90753 (27977617), WAIT_TIMEOUT EXCEEDED MESSAGE NOT TRIGGERED.
  * Bug#85941 (25924324), WASNULL NOT SET AFTER GETBYTES IS CALLED.
  * Bug#28066709, COLLECTION.CREATEINDEX() TEST IS BROKEN AFTER WL#11808 IMPLEMENTATION.
  * Bug#90872 (28027459), FILTERPARAMS CLASS IS NOT NEEDED.
  * Bug#27522054, POSSIBLE ASYNC XPROTOCOL MESSAGE HANDLING PERF ISSUE.
    The "xdevapi.useAsyncProtocol" connection property default value is changed to "false".
  Changes in 8.0.11
  * WL#11293, DevAPI: Support new locking modes : NOWAIT and SKIP LOCKED.
  * Bug#90029 (27678308), FAILURE WHEN GETTING GEOMCOLLECTION COLUMN TYPE.
  * BUG#90024 (27677574), SOME TESTS FAILED AGAINST MYSQL 8.0.5 BECAUSE OF DEPRECATED FEATURES REMOVAL.
  * Bug#86741 (26314325), Multi-Host connection with autocommit=0 getAutoCommit maybe wrong.
  * Bug#27231383, PROVIDE MAVEN-FRIENDLY COMMERCIAL PACKAGES WITHOUT "-BIN".
  * Bug#26819691, SETTING PACKETDEBUGBUFFERSIZE=0 RESULTS IN CONNECTION FAILURE.
  * Bug#88227 (27029657), Connector/J 5.1.44 cannot be used against MySQL 5.7.20 without warnings.
  * Bug#27374581, CONNECTION FAILS WHEN GPL SERVER STARTED WITH TLS-VERSION=TLSV1.2.
  * WL#11419, DevAPI: New document _id generation support.
  * WL#11620, Change caching_sha2_password padding.
  * WL#11604, DevAPI: Add SHA256_MEMORY support.
  * BUG#86278 (26092824), SUPPORT CUSTOM CONSTRUCTION OF SSLSOCKET DURING CONNECTION ESTABLISHMENT.
  * BUG#27226293, JSONNUMBER.GETINTEGER() & NUMBERFORMATEXCEPTION.
  * WL#10527, Clean up Protocol and Session interfaces.
  Changes in 8.0.9
  * WL#11469, Update license header in GPL packages.
  * BUG#27247349, WL#11208 : UNIQUE DOES NOT GIVE ERROR EVEN THOUGH IT IS NOT SUPPORTED.
  * WL#11208, DevAPI: Collection.createIndex.
  * WL#10156, Add setters/getters for connection properties to MysqlDataSource,
    MysqlXADataSource and MysqlConnectionPoolDataSource.
  * WL#11401, DevAPI: Remove configuration API.
  * WL#10619, Ensure compatibility with new data dictionary.
  * BUG#27217264, WL#10937: NULL POINTER EXCEPTION WHEN NULL IS PASSED AS _ID IN COLL.REPLACEONE.
  * WL#10937, DevAPI: ReplaceOne, AddOrReplaceOne, GetOne, RemoveOne.
  * Bug#26723646, JSON_MERGE() FUNCTION IS DEPRECATED IN MYSQL 8.0.
  * Bug#27185332, WL#11210:ERROR IS THROWN WHEN NESTED EMPTY DOCUMENTS ARE INSERTED TO COLLECTION.
  * Bug#27151601, WL#11210: DOCUMENT PATCH EXPRESSIONS ARE NOT SUPPORTED.
  * WL#11210, DevAPI: Modify/MergePatch.
  * Bug#79612 (22362474), CONNECTION ATTRIBUTES LOST WHEN CONNECTING WITHOUT DEFAULT DATABASE.
  * WL#10152, Enable TLSv1.2 on mysqlx.
  * Bug#27131768, NULL POINTER EXCEPTION IN CONNECTION.
  * Bug#88232 (27047676), c/J does not rollback transaction when autoReconnect=true.
  * Bug#88242 (27040063), autoReconnect and socketTimeout JDBC option makes wrong order of client packet.
  * Bug#88021 (26939943), High GC pressure when driver configured with serversideprepared statements.
  * Bug#26724085, CHARSET MAPPING TO BE UPDATED FOR MYSQL 8.0.3.
  * Bug#87704 (26771560), THE STREAM GETS THE RESULT SET ?THE DRIVER SIDE GET WRONG ABOUT GETLONG().
  * Bug#24924097, SERVER GREETING ERROR ISN'T RECOGNIZED DURING HANDSHAKE.
  * Bug#26748909, MASTER : ERROR - NO OPERATIONS ALLOWED AFTER STATEMENT CLOSED FOR TOSTRING().
  * Bug#26266731, CONCUR_UPDATABLE RESULTSET OPERATIONS FAIL AGAINST 8.0 FOR BOOLEAN COLUMN.
  * WL#11239, DevAPI: Remove create table implementation.
  * Bug#27131100, WL#11212 : SAVEPOINT CREATING WITH EMPTY STRING AND SPACE AS NAME.
  * WL#11212, DevAPI: transaction save-points.
  * WL#11060, Support new SHA-256 authentication system.
  * Bug#87826 (26846249), MYSQL JDBC CONNECTOR/J DATABASEMETADATA NULL PATTERN HANDLING IS NON-COMPLIANT.
  * WL#11163, Extract parameter setters, serverPrepare() and serverExecute() to core classes.
  * BUG#26995710, WL#11161 : NULL POINTER EXCEPTION IN EXECUTEBATCH() AND CLOSE().
  * WL#11161, Unify query bindings.
  * WL#8469, Don't extract query text from packets when possible.
  Changes in 8.0.8
  * BUG#26722030, TEST FAILING DUE TO BINARY LOGGING ENABLED BY DEFAULT IN MYSQL 8.0.3.
  * BUG#26722018, TESTS FAILING DUE TO CHANGE IN INFORMATION_SCHEMA.INNODB_SYS_* NAMING.
  * BUG#26750807, MASTER : NULL POINTER EXCEPTION IN SCHEMA.DROPVIEW(NULL).
  * BUG#26750705, MASTER : ERROR - UNSUPPORTED CONVERSION FROM TIME TO JAVA.SQL.DATE.
  * WL#10620, DevAPI: SHA256 Authentication support.
  * WL#10936, DevAPI: Row locking for Crud.Find.
  * WL#9868, DevAPI: Configuration handling interface.
  * WL#10935, DevAPI: Array or Object "contains" operator.
  * WL#9875, Prepare c/J 8.0 for DEB and RPM builds.
  * BUG#26259384, CALLABLE STATEMENT GIVES ERROR IN C/JAVA WHEN RUN AGAINST MYSQL 8.0.
  * Bug#26393132, NULLPOINTEREXCEPTION IS THROWN WHEN TRIED TO DROP A NULL COLLECTION.
  * WL#10532, DevAPI: Cleanup Drop APIs.
  * Bug#87429 (26633984), repeated close of ServerPreparedStatement causes memory leak.
  * Bug#87379 (26646676), Perform actual TLS capabilities check when restricting TLSv1.2.
  * Bug#85601 (25777822), Unit notation is missing in the description of the property involved in the time.
  * Bug#87153 (26501245), INCORRECT RESULT OF DBMD.GETVERSIONCOLUMNS() AGAINST MYSQL 8.0.2+.
  * Bug#78313 (21931572), proxies not handling Object.equals(Object) calls correctly.
  * Bug#85885 (25874048), resultSetConcurrency and resultSetType are swapped in call to prepareStatement.
  * Bug#74932 (20066806), ConnectionImp Doesn't Close Server Prepared Statement (PreparedStatement Leak).
  * WL#10536, Deprecating COM_SHUTDOWN.
  * Bug#25946965, UPDATE THE TIME ZONE MAPPINGS WITH LATEST TZ DATABASES.
  * Bug#20182108, INCLUDE CUSTOM LOAD BALANCING STRATEGY USING PLUGIN API.
  * Bug#26440544, CONNECTOR/J SHOULD NOT USE TX_{READ_ONLY,ISOLATION} WHICH IS PLANNED FOR REMOVAL.
  * Bug#26399958, UNABLE TO CONNECT TO MYSQL 8.0.3.
  * Bug#25650305, GETDATE(),GETTIME() AND GETTIMESTAMP() CALL WITH NULL CALENDAR RETURNS NPE.
  Changes in 8.0.7
  * Bug#26227653, WL#10528 DIFF BEHAVIOUR WHEN SYSTEM PROP JAVAX.NET.SSL.TRUSTSTORETYPE IS SET.
  * WL#10528, DevAPI: Ensure all connectors are secure by default.
  * WL#8305, Remove internal dependency on connection objects.
  * Bug#22972057, X DEVAPI: CLIENT HANGS AFTER CONNECTION FAILURE.
  * Bug#26140577, GIS TESTS ARE FAILING WITH MYSQL 8.0.1.
  * WL#10765, DevAPI: Forbid modify() and remove() with no condition.
  * Bug#26090721, CONNECTION FAILING WHEN SERVER STARTED WITH COLLATION UTF8MB4_DE_PB_0900_AI_CI.
  * WL#10781, enum-based connection properties.
  * Bug#73775 (19531384), DBMD.getProcedureColumns()/.getFunctionColumns() fail to filter by columnPattern.
  * Bug#84324 (25321524), CallableStatement.extractProcedureName() not work when catalog name with dash.
  * Bug#79561 (22333996), NullPointerException when calling a fully qualified stored procedure.
  * Bug#84783 (25490163), query timeout is not working(thread hang).
  * Bug#70704 (17653733), Deadlock using UpdatableResultSet.
  * Bug#66430 (16714868), setCatalog on connection leaves ServerPreparedStatement cache for old catalog.
  * Bug#70808 (17757070), Set sessionVariables in a single query.
  * Bug#77192 (21170603), Description for the Property replicationConnetionGroup Missing from the Manual.
  * Bug#83834 (25101890), Typo in Connector/J error message.
  * WL#10531, Support utf8mb4 as default charset.
  * Bug#85555 (25757019), useConfigs Can't find configuration template named, in mysql-connector-java 6.x
  * WL#10529, Move version number to 8.0.
  * WL#10530, DevAPI: Remove XSession, rename NodeSession to Session.
  * Bug#23510958, CONCURRENT ASYNC OPERATIONS RESULT IN HANG.
  * Bug#23597281, GETNODESESSION() CALL WITH SSL PARAMETERS RETURNS CJCOMMUNICATIONSEXCEPTION.
  * Bug#25207784, C/J DOESN'T FOLLOW THE FINAL X DEVAPI MY-193 SPECIFICATION.
  * Bug#25494338, ENABLEDSSLCIPHERSUITES PARAMETER NOT WORKING AS EXPECTED WITH X-PLUGIN.
  * Bug#84084 (25215008), JAVA.LANG.ARRAYINDEXOUTOFBOUNDSEXCEPTION ON ATTEMPT TO GET VALUE FROM RESULTSET.
  * WL#10553, Add mapping for Japanese utf8mb4 collation.
  * Bug#25575103, NPE FROM CREATETABLE() WHEN SOME OF THE INPUTS ARE NULL.
  * Bug#25575156, NPE FROM CREATEVIEW() WHEN SOME OF THE INPUTS ARE NULL.
  * Bug#25636947, CONNECTION USING MYSQL CLIENT FAILS IF WE USE THE SSL CERTIFICATES FROM C/J SRC.
  * Bug#25687718, INCORRECT TIME ZONE IDENTIFIER IN STATEMENTREGRESSIONTEST.
  * Bug#25556597, RESULTSETTEST.TESTPADDING UNIT TEST IS FAILING IN 5.1.41 RELEASE PACKAGE.
  * Bug#25517837, CONNECT PERFORMNACE DEGRADED BY 10%% IN 5.1.41.
  * Bug#25504578, CONNECT FAILS WHEN CONNECTIONCOLLATION=ISO-8859-13.
  * Bug#25438355, Improper automatic deserialization of binary data.
  * Bug#70785 (17756825), MySQL Connector/J inconsistent init state for autocommit.
  * Bug#66884: Property 'elideSetAutoCommits' temporarily  defaults to 'false' until this bug is fixed.
  * Bug#75615 (21181249), Incorrect implementation of Connection.setNetworkTimeout().
  * Bug#81706 (23535001), NullPointerException in driver.
  * Bug#83052 (25048543), static method in com.mysql.jdbc.Util relies on null object.
  * Bug#69526 (17035755), 'Abandoned connection cleanup thread' at mysql-connector-java-5.1.25.
  * Bug#82826 (24942672), Unneeded version requirement for javax.net.ssl Import-Package on OSGi MANIFEST.MF.
  Changes in 6.0.6
  * Added Core TLS/SSL options for the mysqlx URI scheme.
  * Updated collations map.
  * Bug#24350526, UNEXPECTED BEHAVIOUR OF IS_NUMBER_SIGNED API IN C/JAVA.
  * Bug#82707 (24512766), WRONG MILLI SECOND VALUE RETURNED FROM TIMESTAMP COLUMN.
  * Bug#82005 (23702040), JDBCDATEVALUEFACTORY FAILS TO PARSE SOME DATES.
  * Bug#83725 (25056803), NPE IN XPROTOCOL.GETPLUGINVERSION() WITH MYSQL 5.7.17.
  * Bug#24525461, UPDATABLE RESULTSET FEATURE FAILS WHEN USESERVERPREPSTMTS=TRUE.
  * Bug#24527173, QUERY EXECUTION USING PREPARED STMT FAILS WHEN USECURSORFETCH=TRUE.
  * Bug#82964 (24658016), JSR-310 DATA TYPES CREATED THROUGH JAVA.SQL TYPES.
  * Bug#81202 (23188159), RESULTSETIMPL.GETOBJECT THROWS NULLPOINTEREXCEPTION WHEN FIELD IS NULL.
  * Bug#22931277, COLUMN.GETTYPE() RETURNS ERROR FOR VALID DATATYPES.
  * BUG#24471057, UPDATE FAILS WHEN THE NEW VALUE IS OF TYPE DBDOC WHICH HAS ARRAY IN IT.
  * Bug#81691 (23519211), GETLASTDOCUMENTIDS() DOESN'T REPORT IDS PROVIDED BY USER.
  * Bug#82826 (24942672), Unneeded version requirement for javax.net.ssl Import-Package on OSGi MANIFEST.MF.
  Changes in 6.0.5
  * BUG#82896 (24613062), Unexpected behavior on attempt to connect to JDBC driver with unsupported URL.
  * Added client-side failover during XSession initialization for multi-router configuration.
  * Removed Extension interface. All extension classes now implement their specific interfaces.
  * Bug#22988922, GETLENGTH() RETURNS -1 FOR LONGBLOB AND LONGTEXT FIELDS.
  * Bug#24619829, NEW FAILURES IN C/JAVA UNITTESTS AGAINST MYSQL 8.0.
  * Bug#75209 (20212882), Set useLocalTransactionState may result in partially committed transaction.
  * Bug#48346 (11756431), Communications link failure when reading compressed data with compressed=true.
  * Bug#80631 (22891845), ResultSet.getString return garbled result with json type data.
  * Bug#64188 (13702433), MysqlXAConnection.MYSQL_ERROR_CODES_TO_XA_ERROR_CODES is missing XA error codes.
  * Bug#72632 (18759269), NullPointerException for invalid JDBC URL.
  * Bug#82115 (23743956), Some exceptions are intercepted twice or fail to set the init cause.
  * Bug#78685 (21938551), Wrong results when retrieving the value of a BIT column as an integer.
  * Bug#80615 (22954007), prepared statement leak when rewriteBatchedStatements=true and useServerPrepStmt.
  * Extended X DevAPI with flexible parameter lists.
  * Added a virtual NodeSession to X DevAPI.
  Changes in 6.0.4
  * X DevAPI URL prefix changed from "mysql:x:" to "mysqlx:".
  * Bug#24301468 X DEVAPI SSL CONNECTION FAILS ON WINDOWS
  * The X DevAPI Table object now represents both database tables and views.
  * Added support for matching against pattern for X DevAPI list_objects calls.
  * Added Schema.getCollections(String pattern) and Schema.getTables(String pattern) interface methods.
  * Switched to "mysqlx" namespace for X DevAPI StmtExecute messages.
    This change is incompatible to MySQL server versions < 5.7.14.
  * Bug#82046 (23743947), MYSQL CONNECTOR JAVA OSGI METADATA BROKEN.
  * Bug#21690043, CONNECT FAILS WHEN PASSWORD IS BLANK.
  * Bug#22931433, GETTING VALUE OF BIT COLUMN RESULTS IN EXCEPTION.
  Changes in 6.0.3
  * Bug#23535571, EXCESSIVE MEMORY USAGE WHEN ENABLEPACKETDEBUG=TRUE.
  * Bug#23212347, ALL API CALLS ON RESULTSET METADATA RESULTS IN NPE WHEN USESERVERPREPSTMTS=TRUE.
  * Bug#23201930, CLIENT HANG WHEN RSLT CUNCURRENCY=CONCUR_UPDATABLE AND RSLTSET TYPE=FORWARD_ONLY.
  * Bug#23188498, CLIENT HANG WHILE USING SERVERPREPSTMT WHEN PROFILESQL=TRUE AND USEIS=TRUE.
  * Bug#22678872, NPE DURING UPDATE WITH FABRIC.
  * Bug#71131 (18068303), Poor error message in CallableStatement.java.
  * Bug#59462 (16736619), ConcurrentModificationException inside ConnectionImpl.closeAllOpenStatements().
  * Bug#22848249, LOADBALANCECONNECTIONGROUPMANAGER.REMOVEHOST() NOT WORKING AS EXPECTED.
  * Bug#22730682, ARRAYINDEXOUTOFBOUNDSEXCEPTION FROM CONNECTIONGROUPMANAGER.REMOVEHOST().
  * Bug#77171 (21181466), On every connect getting sql_mode from server creates unnecessary exception.
  * Bug#79343 (22353759), NPE in TimeUtil.loadTimeZoneMappings causing server time zone value unrecognized.
  * Bug#22038729, X DevAPI: Any API call after a failed CALL PROC() results in hang
  * Replace Schema.drop(), Collection.drop() by X DevAPI's session.dropSchema() and session.dropCollection().
  * Added session.dropTable().
  * Bug#22932078, GETTIMESTAMP() RETURNS WRONG VALUE FOR FRACTIONAL PART
  * Extracted packet readers from MysqlaProtocol.
  * Bug#22972057, X protocol CLIENT HANGS AFTER CONNECTION FAILURE
  * Bug#23044312, NullPointerException in X protocol AsyncMessageReader due to race condition
  * Returned support for MySQL 5.5 and 5.6.
  Changes in 6.0.2
  * Deprecate the EOF packet.
  * Bug#75956, Inserting timestamps using a server PreparedStatement and useLegacyDatetimeCode=false
  * Bug#22385172, CONNECTOR/J MANIFEST DOES NOT EXPOSE FABRIC (OSGi).
  * Bug#22598938, FABRICMYSQLDATASOURCE.GETCONNECTION() NPE AFTER SWITCHOVER.
  * Bug#21286268, CONNECTOR/J REPLICATION USE MASTER IF SLAVE IS UNAVAILABLE.
  * Bug#21296840 & Bug#17910835, Server information in a group from Fabric is not refreshed after expired TTL.
  * Bug#56122 (11763419), JDBC4 functionality failure when using replication connections.
  * Added support for TLSv1.1 and TLSv1.2
  * Bug#78961 (22096981), Can't call MySQL procedure with InOut parameters in Fabric environment.
  * Bug#56100 (11763401), Replication driver routes DML statements to read-only slaves.
  * StandardSSLSocketFactory implements SocketMetadata.
  * Bug#21978216, GETTYPEINFO REPORT MAXIMUM PRECISION OF 255 FOR VARBINARY.
  * Bug#78706 (21947042), Prefer TLS where supported by MySQL Server.
  * Bug#21934573, FABRIC CODE INVOLVED IN THREAD DEADLOCK.
  * Bug#21876798, CONNECTOR/J WITH MYSQL FABRIC AND SPRING PRODUCES PROXY ERROR.
  Changes in 6.0.1
  * Removed useJvmCharsetConverters connection property. JVM charset converters are now used in all cases.
  * Refactored value decoding and removed all date/time connection properties
  * Refactored connection properties
  * Assume existence of INFORMATION_SCHEMA.PARAMETERS (and thus MySQL 5.5) when preparing stored procedure calls.
  * Removed retainStatementAfterResultSetClose connection property.
  * Null-merge of Bug#54095 (11761585) fix.
  * Removed support code for MySQL server versions < 5.7.
  * Bug#76859 (20969312), DBMD getColumns using I_S doesn't have column IS_GENERATEDCOLUMN as per JDBC 4.1.
  * Added support for GENERATED COLUMNS.
  * Update Time Zone mappings with IANA Time Zone database tsdata2015f and Unicode CLDR v.28.
  * Update DatabaseMetaData SQL keywords.
  * Added tests for Optimizer hints syntax introduced in MySQL 5.7.7.
  * Bug#21860833, JSON DATA TYPE DOESN'T WORK WITH SSPS.
  * Added support for JSON data type.
  * Added support for JDBC 4.2 new features.
  * Bug#16634180, LOCK WAIT TIMEOUT EXCEEDED CAUSES SQLEXCEPTION, SHOULD CAUSE SQLTRANSIENTEXCEPTION
  * Bug#75849 (20536592), NPE in abortInternal() method on line 1358 of ConnectionImpl.
  * Bug#78106 (21648826), Potential memory leak with inflater.
  * Bug#78225 (21697684), DEFAULT NO_AUTO_CREATE_USER SQL_MODE BEHAVIOR BROKE SOME TESTS
  * Bug#77665 (21415165), JDBC fails to connect with MySQL 5.0.
  * Bug#77681 (21429909), rewrite replace sql like insert when rewriteBatchedStatements=true (contribution).
  * Bug#77449 (21304726) Add 'truncateFractionalSeconds=true|false' property (contribution).
  * Bug#50348 (11758179), mysql connector/j 5.1.10 render the wrong value for dateTime column in GMT DB.
  * Bug#75670 (20433047), Connection fails with "Public Key Retrieval is not allowed" for native auth.
  * Bug#76187 (20675539), getTypeInfo report maximum precision of 255 for varchar.
  * Add test for new syntax 'ALTER TABLE ... DISCARD|IMPORT PARTITION ...' introduced in MySQL 5.7.4.
  * Bug#20727196, GETPROCEDURECOLUMNS() RETURNS EXCEPTION FOR FUNCTION WHICH RETURNS ENUM/SET TYPE.
  * Bug#19803348, GETPROCEDURES() RETURNS INCORRECT OUTPUT WHEN USEINFORMATIONSCHEMA=FALSE.
  * Bug#21215151, DATABASEMETADATA.GETCATALOGS() FAILS TO SORT RESULTS.
  * Bug#72630 (18758686), NullPointerException during handshake in some situations
  * Bug#20825727, CONNECT FAILURE WHEN TRY TO CONNECT SHA USER WITH DIFFERENT CHARSET.
  * Flag RowDataDynamic.isInterrupted removed as it isn't needed.
  * Bug#20518653, XSL FILES IN PACKAGES
  * Bug#20804635, GETTIME() AND GETDATE() FUNCTIONS FAILS WHEN FRACTIONAL PART EXISTS
  * Bug#62452 (16444069), NPE thrown in JDBC4MySQLPooledException when statement is closed.
  * BUG#70927 (17810800), Connector/J COM_CHANGE_USER handling is broken
  * Bug#75335 (20283655), Maven artifact for Connector/J is missing source jar.
  * BUG#75592 (20408891), "SHOW VARIABLES WHERE" is expensive.
  * Bug#75113 (20821888), Fail in failover of the connection in MySQL fabric
  * Bug#72077 (18425861), Fabric connection with username to a server with disabled auth throws NPE
  * Add test for already fixed Bug#72546 (18719760), C/J Fabric createGroup() throws ClassCastException
  * Bug#77217 (21184949), ClassCastException when executing a streaming PreparedStatement with Fabric
  * Bug#19536760, GETSTRING() CALL AFTER RS.RELATIVE() RETURNS NULLPOINTEREXCEPTION
  * BUG#20453712, CLOB.SETSTRING() WITH VALID INPUT RETURNS EXCEPTION
  * BUG#20453671, CLOB.POSITION() API CALL WITH CLOB INPUT RETURNS EXCEPTION
  * Bug#20685022, SSL CONNECTION TO MYSQL 5.7.6 COMMUNITY SERVER FAILS.
  * Bug#20606107, TEST FAILURES WHEN RUNNING AGAINST 5.7.6 SERVER VERSION
  * Bug#20533907, BUG#20204783 FIX EXPOSES WRONG BEAHAVIORS IN FAILOVER CONNECTIONS.
  * Bug#20504139, GETFUNCTIONCOLUMNS() AND GETPROCEDURECOLUMNS() RETURNS ERROR FOR VALID INPUTS.
  * Expose PreparedStatment.ParseInfo for external usage, with no capture of the connection
  * Bug#75309 (20272931), mysql connector/J driver in streaming mode will in the blocking state.
  * New property 'readOnlyPropagatesToServer' controls the implicit propagation of read only transaction access mode to server.
  * Bug#54095 (11761585), Unnecessary call in newSetTimestampInternal.
  * Bug#67760 (15936413), Deadlock when concurrently executing prepared statements with Timestamp objects.
  * Bug#71084 (18028319), Wrong java.sql.Date stored if client and server time zones differ.
  * Bug#75080 (20217686), NullPointerException during setTimestamp on Fabric connection.
  * Bug#75168 (20204783), loadBalanceExceptionChecker interface cannot work using JDBC4/JDK7.
  * Bug#73595 (19465516), Replace usage of StringBuffer in JDBC driver.
  * Bug#18925727, SQL INJECTION IN MYSQL JDBC DRIVER.
  * Bug#74998 (20112694), readRemainingMultiPackets not computed correctly for rows larger than 16 MB.
  * Bug#73012 (19219158), Precedence between timezone options is unclear.
  * Implement support for connecting through SOCKS proxies (WL#8105).
  * Ant buildfile reworked to fix incompatibilities with latest Eclipse
  * Bug#18474141, TESTSUITE.FABRIC TEST CASES FAIL IF NO FABRIC.TESTSUITE PROPERTIES PROVIDED
  * Bug#19383371, CONNECT USING MYSQL_OLD_PASSWORD USER FAILS WHEN PWD IS BLANK
  * Bug#17441747, C/J DOESN'T SUPPORT XA RECOVER OUTPUT FORMAT CHANGED IN MYSQL 5.7.
  * Bug#19145408, Error messages may not be interpreted according to the proper character set
  * Bug#19505524, UNIT TEST SUITE DOES NOT CONSIDER ALL THE PARAMETERS PASSED TO BUILD.XML.
  * Bug#73474 (19365473), Invalid empty line in MANIFEST.MF
  * Bug#70436 (17527948), Incorrect mapping of windows timezone to Olson timezone.
  * Bug73163 (19171665), IndexOutOfBoundsException thrown preparing statement.
  * Added support for gb18030 character set
  * Bug#73663 (19479242), utf8mb4 does not work for connector/j >=5.1.13
  * Bug#73594 (19450418), ClassCastException in MysqlXADataSource if pinGlobalTxToPhysicalConnection=true
  * Bug#19354014, changeUser() call results in "packets out of order" error when useCompression=true.
  * Bug#73577 (19443777), CHANGEUSER() CALL WITH USECOMPRESSION=TRUE COULD LEAD TO IO FREEZE
  * Bug#19172037, TEST FAILURES WHEN RUNNING AGAINST 5.6.20 SERVER VERSION
  * Bug#71923 (18344403), Incorrect generated keys if ON DUPLICATE KEY UPDATE not exact.
  * Bug#72502 (18691866), NullPointerException in isInterfaceJdbc() when using DynaTrace
  * Bug#72890 (18970520), Java jdbc driver returns incorrect return code when it's part of XA transaction.
  * Fabric client now supports Fabric 1.5. Older versions are no longer supported.
  * Bug#71672 (18232840), Every SQL statement is checked if it contains "ON DUPLICATE KEY UPDATE" or not.
  * Bug#73070 (19034681), Preparing a stored procedure call with Fabric results in an exception
  * Bug#73053 (19022745), Endless loop in MysqlIO.clearInputStream due to Linux kernel bug.
  * Bug#18869381, CHANGEUSER() FOR SHA USER RESULTS IN NULLPOINTEREXCEPTION
  * Bug#62577 (16722757), XA connection fails with ClassCastException
  * Bug#18852587, CONNECT WITH A USER CREATED USING SHA256_PASSWORD PLUGIN FAILS WHEN PWD IS BLANK
  * Bug#18852682, TEST TESTSHA256PASSWORDPLUGIN FAILS WHEN EXECUTE AGAINST COMMERCIAL SERVER
  * failing tests when running test suite with Java 6+.
  * Bug#72712 (18836319), No way to configure Connector JDBC to not do extra queries on connection
- Remove hibernate-check.patch (fixed upstream)
- Remove mysql-connector-java-jdbc-4.1.patch (fixed upstream)
- Remove disable-testsuite.patch mysql-connector-java-jdbc-4.1.patch (fixed upstream)
- Remove compile-jdk7.patch (fixed upstream)
- Remove mysql-connector-java-sourcetarget.patch (fixed upstream)
- Refresh javac-check.patch
- Adjust log4j/log4j-mini dependencies to account for the lack of
  log4j12/log4jmini12 Provides in some code streams.
* Wed Jul  1 2020 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Update to 5.1.49 [bsc#1173600, CVE-2020-2875, CVE-2020-2933, CVE-2020-2934]
- Changes in 5.1.49:
  * INSERT..VALUE..lead to invalidation of batch insert.
  * CLIENT HANG WHEN LOADBALANCESTRATEGY IS BESTRESPONSETIME.
  * Remove third-party libraries from sources and bundles.
  * PREPAREDSTATEMENT.SETOBJECT(I, "FALSE", TYPES.BOOLEAN) ALWAYS SETS TRUE OR 1.
  * Not recommended default for 'allowLoadLocalInfile'.
  * Disable external entities in Fabric's XML parser.
  * INCORRECT DATE ERROR WHEN CALLING GETMETADATA ON PREPARED STATEMENT.
- Changes in 5.1.48:
  * COMMUNITY README AND README.TXT FILES HAS THE WRONG YEAR (2018).
  * REGRESSION UNIT TESTS FAILS WHEN THE 8.0 SERVER'S CHARSET IS SET TO DEFAULT UTF8MB4.
  * Update README.md and add new CONTRIBUTING.md.
  * Improve DatabaseMetaData.getSQLKeywords() to include new reserved words.
  * Parameter metadata inferred incorrectly when procedure or function doesn't exist.
  * Can't execute a stored procedure if exists function with same name.
  * PSTMT.EXECUTEUPDATE() FAILS WHEN SQL MODE IS NO_BACKSLASH_ESCAPES.
  * SYNTAX ERROR ON RESULTSET.UPDATEROW() WITH SQL_MODE NO_BACKSLASH_ESCAPES.
  * PREPAREDSTATEMENT.SETTIMESTAMP NULLPOINTEREXCEPTION.
  * Support new utf8mb4 bin collation.
  * GETTABLENAME() RETURNS NULL FOR A QUERY HAVING COUNT(*) WITH JDBC DRIVER V8.0.12.
  * SETTING LOGSLOWQUERIES SHOULD NOT AUTOMATICALLY ENABLE PROFILESQL FOR QUERIES.
  * PROFILEREVENT HOSTNAME HAS NO GETTER().
  * CONNECTOR J WITH PROFILESQL - LOG CONTAINS LOTS OF STACKTRACE DATA.
  * PROFILEREVENT.PACK() THROWS ARRAYINDEXOUTOFBOUNDSEXCEPTION.
  * CHARACTERS GET GARBLED IN CONCAT() IN PS WHEN USECURSORFETCH=TRUE.
  * javax.net.ssl.SSLException: closing inbound before receiving peer's close_notify.
  * PLEASE AVOID SHOW PROCESSLIST IF POSSIBLE.
  * Wrong defaults on collation mappings.
  * ADD MAPPING FOR UTF8MB4_ZH_0900_AS_CS COLLATION.
  * mysql-connector in bootclasspath causing memory leak.
- Update mysql-connector-java-jdbc-4.1.patch
* Tue Oct  1 2019 Fridrich Strba <fstrba@suse.com>
- Build against the new compatibility packages log4j12/log4j12-mini
- Clean the spec file by spec-cleaner
* Mon Nov  5 2018 Pedro Monreal Gonzalez <pmonrealgonzalez@suse.com>
- Updated to 5.1.47
  - Bug#28449601, MASTER : UNITTEST FOR BUG#22305979 (TESTBUG22305979) STILL FAILS ON QA SETUP.
  - Bug#81063 (23098159), w/ rewriteBatchedStatements, when 2 tables involved, the rewriting not correct.
  - Bug#84813 (25501750), rewriteBatchedStatements fails in INSERT.
  - Fix for Bug#81196 (23227334), CONNECTOR/J NOT FOLLOWING DATABASE CHARACTER SET.
  - Bug#72609 (18749544), SETDATE() NOT USING A PROLEPTIC GREGORIAN CALENDAR.
  - Bug#87534 (26730196), UNION ALL query fails when useServerPrepStmts=true
    on database connection. Test case only. Base bug fixed in MySQL 5.7.22.
  - Bug#89948 (27658489), Batched statements are not committed for useLocalTransactionState=true.
  - BUG#80532 (22847443), ENCODING OF RESULTSET.UPDATEROW IS BROKEN FOR NON ASCII CHARCTERS.
  - BUG#22305979, WRONG RECORD UPDATED IF SENDFRACTIONALSECONDS=FALSE AND SMT IS SCROLLABLE.
  - BUG#90024 (27677574), SOME TESTS FAILED AGAINST MYSQL 8.0.5 BECAUSE OF DEPRECATED FEATURES REMOVAL.
- Updated to 5.1.46
  - WL#11629, Change caching_sha2_password padding.
  - Bug#86741 (26314325), Multi-Host connection with autocommit=0 getAutoCommit maybe wrong.
  - Bug#27231383, PROVIDE MAVEN-FRIENDLY COMMERCIAL PACKAGES WITHOUT "-BIN".
  - Bug#26819691, SETTING PACKETDEBUGBUFFERSIZE=0 RESULTS IN CONNECTION FAILURE.
  - WL#11200, Add caching_sha2_password support.
  - Bug#88227 (27029657), Connector/J 5.1.44 cannot be used against MySQL 5.7.20 without warnings.
  - Bug#27374581, CONNECTION FAILS WHEN GPL SERVER STARTED WITH TLS-VERSION=TLSV1.2.
  - Bug#79612 (22362474), CONNECTION ATTRIBUTES LOST WHEN CONNECTING WITHOUT DEFAULT DATABASE.
- Updated to 5.1.45
  - Bug#27131768, NULL POINTER EXCEPTION IN CONNECTION.
  - Bug#88232 (27047676), c/J does not rollback transaction when autoReconnect=true.
  - Bug#88242 (27040063), autoReconnect and socketTimeout JDBC option makes wrong order of client packet.
  - Bug#88021 (26939943), High GC pressure when driver configured with serversideprepared statements.
  - Bug#26724085, CHARSET MAPPING TO BE UPDATED FOR MYSQL 8.0.3.
  - Bug#26794652, TEST FAILING DUE TO BINARY LOGGING ENABLED BY DEFAULT IN MYSQL 8.0.3.
  - Bug#26794602, TESTS FAILING DUE TO CHANGE IN INFORMATION_SCHEMA.INNODB_SYS_* NAMING.
  - Bug#87704 (26771560), THE STREAM GETS THE RESULT SET ?THE DRIVER SIDE GET WRONG ABOUT GETLONG().
- Updated to 5.1.44
  - Bug#87429 (26633984), repeated close of ServerPreparedStatement causes memory leak.
  - Bug#87379 (26646676), Perform actual TLS capabilities check when restricting TLSv1.2.
  - Bug#85601 (25777822), Unit notation is missing in the description of the property involved in the time.
  - Bug#87153 (26501245), INCORRECT RESULT OF DBMD.GETVERSIONCOLUMNS() AGAINST MYSQL 8.0.2+.
  - Bug#26440544, CONNECTOR/J SHOULD NOT USE TX_{READ_ONLY,ISOLATION} WHICH IS PLANNED FOR REMOVAL.
- Rebased patch mysql-connector-java-jdbc-4.1.patch
* Fri Oct  6 2017 fstrba@suse.com
- Fix build with jdk9
- Added patch:
  * mysql-connector-java-sourcetarget.patch
    + Don't hardcode java source and target levels; specify them
    on command-line.
* Fri Sep 29 2017 fstrba@suse.com
- Don't condition the maven defines on release version, but on
  _maven_repository being defined
* Sun Sep 10 2017 fstrba@suse.com
- Require for building java-devel = 1.8.0, since this package needs
  a javac compiler able to build with source and target level 1.5
* Mon Aug 21 2017 pmonrealgonzalez@suse.com
- Update to version 5.1.43
  * Fixed problems connecting to MYSQL 8.0.3.
  * Deprecating COM_SHUTDOWN
  * GETDATE(),GETTIME() AND GETTIMESTAMP() called with NULL
    calendar returs NPE
  * C/J 5.1 GIS tests are failing with MYSQL 8.0.1C/J 5.1 GIS
  * Updated time zone mappings with latest TZ databases
  * For a full list of fixed issues see CHANGES or:
    http://dev.mysql.com/doc/relnotes/connector-j/en/news-5-1.html
* Fri May 19 2017 dziolkowski@suse.com
- New build dependency: javapackages-local
- cleaned spec using spec-cleaner
* Thu May 18 2017 tchvatal@suse.com
- Hardcode requirement for java 1.8 or newer to build
* Thu May 18 2017 tchvatal@suse.com
- Drop patch use-classpath-in-tests.patch
- Add patch disabling testsuite:
  * disable-testsuite.patch
- Drop patch extra-libs-build.patch:
  * Rather use the thing to propagate some wrongly found libs
- Drop patch no-jdk5-requirement.patch:
  * Simply override the value in ant command
- Add patch hibernate-check.patch to remove hibernate check
- Add patch compile-jdk7.patch to compile with old JDK versions
* Thu May 18 2017 tchvatal@suse.com
- Version update to 5.1.42 bsc#1035210 bsc#1035697 bsc#1035211:
  * CVE-2017-3589 CVE-2017-3523 CVE-2017-3586
  * http://dev.mysql.com/doc/relnotes/connector-j/en/news-5-1.html
- Remove upstreamed mysql-connector-java-5.1.35-CVE-2017-3523.patch
- Refresh patch extra-libs-build.patch
- Drop obsolete patch jdk6-check-use-jdk7.patch
- Refresh patch no-jdk5-requirement.patch
- Attempt to refresh mysql-connector-java-jdbc-4.1.patch
  * Partialy merged by upstream, many conflicts
- Add patch to relax compiler check:
  * javac-check.patch
* Tue May  2 2017 pmonrealgonzalez@suse.com
- Fix for CVE-2017-3523 (bsc#1035697)
  * Unexpected automatic deserialisation of Java objects
  * Affected software: MySQL Connector/J
  * Remote Code Execution Vulnerability
- Added patch: mysql-connector-java-5.1.35-CVE-2017-3523.patch
* Thu Jun 11 2015 tchvatal@suse.com
- Fix the patches to allow jdbc3 build and reenable it:
  * mysql-connector-java-jdbc-4.1.patch
  * no-jdk5-requirement.patch
* Tue Apr 21 2015 tchvatal@suse.com
- Update to 5.1.35 (see CHANGES for full list of issues)
  bnc#927981 CVE-2015-2575:
  * http://dev.mysql.com/doc/relnotes/connector-j/en/news-5-1.html
- Remove not applicable patch:
  * mysql-connector-java-7-jdbc-4.1.patch
- Do not explicitely check for jdk6 but be happy with 7 and 8:
  * jdk6-check-use-jdk7.patch
- Do not require hibernate4 to actually build:
  * extra-libs-build.patch
- Do not build jdk5 depending jdbc3:
  * no-jdk5-requirement.patch
- Add and rebase jdbc4.1 patch:
  * mysql-connector-java-jdbc-4.1.patch
- Add new patch to build tests:
  * use-classpath-in-tests.patch
* Wed Mar 18 2015 tchvatal@suse.com
- Fix build with new javapackages-tools
* Fri Jun 27 2014 tchvatal@suse.com
- Cleanup with spec-cleaner
- Try to build on SLE_11
* Thu Sep 19 2013 mvyskocil@suse.com
- update to 5.1.25 (see CHANGES for full list)
  * support for Connection Attributes when used with MySQL Server versions (5.6+).
  5.1.24
  * support of password expiration protocol. This introduces new boolean
    connection property disconnectOnExpiredPasswords.
  5.1.23
  * added support of password expiration protocol.
  * driver now allows the mechanism for caching MySQL server configuration
    values replaceable at runtime.
  * Connection.setReadOnly() will take advantage of server-side support for
    read-only transactions present in MySQL-5.6 and newer. Calling .isReadOnly()
    will incur a round-trip if useLocalSessionState.
  5.1.22
  * support of ON UPDATE CURRENT_TIMESTAMP for TIMESTAMP and DATETIME fields.
  5.1.21
  * new built-in authentication plugin
    com.mysql.jdbc.authentication.Sha256PasswordPlugin ("sha256_password").
  * Added new built-in authentication plugin
    com.mysql.jdbc.authentication.MysqlClearPasswordPlugin ("mysql_clear_password").
    It allows C/J based clients to connect to MySQL accounts.
  * the ability to add new client-side prepared statement parse info caches
  * implemented several JDBC-4.1 methods from Java-7:
  5.1.19:
  * Added support for pluggable authentication via the com.mysql.jdbc.AuthenticationPlugin
- rebase and rename mysql-connector-java-5.1.19-java7.patch to
  * mysql-connector-java-7-jdbc-4.1.patch
* Fri Sep 13 2013 pgajdos@suse.com
- add jpackages-tools to buildrequires
* Fri Aug 23 2013 mvyskocil@suse.com
- use add_maven_depmap provided by javapackages-tools
* Wed Jun 20 2012 mvyskocil@suse.cz
- build require java-devel >= 1.6.0 as well
* Mon Jun 18 2012 mvyskocil@suse.cz
- fix a build with jdk7 (build jdbc 3.0 with gcj)
- remove some obsoleted macros (gcj, jboss)
- remove jars from source file as well
* Fri May  4 2012 mvyskocil@suse.cz
- remove the docs/ from source tarball due license issues
* Fri Apr 27 2012 mvyskocil@suse.cz
- update to 5.1.19
  * plugable authentication via com.mysql.jdbc.AuthenticationPlugin
  * retrieve servet charset name using index
  * ability to determine if the connection is against server on the same host
  * added slf4j logging adapter
  * and many more features and bugfixes
- removed -javadoc patch and package
- add maven pom
* Thu Sep 11 2008 anosek@suse.cz
- updated to version 5.1.6
  - introduces driver which conforms to the JDBC 4.0 specifications.
    However this was disabled because of missing dependencies
- dropped obsoleted patch (build_xml.patch)
- added patch (disableJDBC4.patch) taken from Debian
* Thu Aug  7 2008 mvyskocil@suse.cz
- update to the 5.0.8 (improved spec from jpackage.org)
  - fix of [bnc#99151]
- added two new subpackages (javadoc and manual)
- removed the dependency on jboss4
- add a support for build with java6 and java5 together (ia64 build fix)
- use source="1.5" and target="1.5"
* Thu Jul 17 2008 coolo@suse.de
- trying to avoid another build cycle
* Wed Sep 27 2006 skh@suse.de
- don't use icecream
- use source="1.4" and target="1.4" for build with java 1.5
* Tue Feb  7 2006 jsmeix@suse.de
- Current version 3.1.12 from JPackage.org
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Jul 28 2005 jsmeix@suse.de
- Adjustments in the spec file.
* Mon Jul 18 2005 jsmeix@suse.de
- Current version 3.1.8 from JPackage.org
* Fri Feb 18 2005 skh@suse.de
- update to version 3.1.6
- don't use icecream
* Thu Sep  2 2004 skh@suse.de
- Initial package created with version 3.0.11 (JPackage 1.5)
